@@ -4,6 +4,8 @@
 # @Remark   : 数据库操作方法基类，用于执行数据库方法及返回值校验
 from typing import Union, Any, List
 
+from mxsoftpy import Model
+
 from .globals import request
 from .db_def.def_type import type_map
 from .exception import DBError, DataError
@@ -22,13 +24,7 @@ class BaseDB:
         """
         self.__chl = CBSHandleLoc()
         self.__handle = None
-        try:
-            from utils.conf.mxconfig import MxConfig
-            self.host = host or MxConfig.HOST
-            self.port = port or MxConfig.PORT
-        except (ModuleNotFoundError, ImportError, AttributeError):
-            self.host = host or '127.0.0.1'
-            self.port = port or 8123
+        self.host, self.port = host, port
         self.__cls_value(self.host, self.port)
 
     @staticmethod
@@ -121,7 +117,7 @@ class BaseDB:
         value_type = type_map[item[2]] if len(item) == 3 else type_map[type(item[1]).__name__]
         return value_type
 
-    def _generation_items(self, items: Union[List[tuple], dict]) -> list:
+    def _generation_items(self, items: Union[List[tuple], dict, Model]) -> list:
         """
         生成符合数据库插入格式的数据
         """
@@ -135,6 +131,14 @@ class BaseDB:
                     data_list.append({'name': k, 'value': v, 'valuetype': type_map[type(v).__name__]})
                 else:
                     raise DataError('未知的value_type, 类型：%s ,值：%s' % (str(type(v)), v))
+        elif isinstance(items, Model):
+            for field in items.__fields__.values():
+                if type_map.get(field.type_.__name__):
+                    data_list.append({'name': field.name, 'value': getattr(items, field.name),
+                                      'valuetype': type_map[field.type_.__name__]})
+                else:
+                    raise DataError('不支持此解析字段的类型，字段名: %s, 解析到的类型: %s' % (field.name, field.type_.__name__))
+
         else:
             raise DataError('错误的数据类型，items应为列表或字典')
 
@@ -167,18 +171,44 @@ class BaseDB:
         return host, port
 
     @staticmethod
-    def _get_file(file: str) -> str:
+    def _get_file() -> str:
         """
         判断所使用的数据库，优先层次：
-                                1：传入参数
-                                2：当前公司同名数据库
-                                3：base
+                                1：当前公司同名数据库
+                                2：base
         """
-        if file:
-            return file
+        # noinspection PyBroadException
+        try:
+            return request().company
+        except Exception:
+            return 'base'
+
+    def _get_host_port(self, file: str) -> tuple:
+        """
+        判断使用的ip及端口，优先层次：
+                                1：实例化时传递的参数
+                                2：c++缓存的数据
+                                3：python配置的数据
+                                4：默认数据
+
+        :param file:
+        :return:
+        """
+        if self.host and self.port:
+            return self.host, self.port
+
         else:
+            from bsmiddle import DbServer_GetDataSource
             # noinspection PyBroadException
             try:
-                return request().company
-            except Exception:
-                return 'base'
+                host, port = DbServer_GetDataSource(request().company, file)
+            except BaseException:
+                try:
+                    from utils.conf.mxconfig import MxConfig
+                    host = MxConfig.HOST
+                    port = MxConfig.PORT
+                except (ModuleNotFoundError, ImportError, AttributeError):
+                    host = '127.0.0.1'
+                    port = 8123
+
+            return self.host or host, self.port or port
